## `citros report`

A citros report is a collection of `data from a batch of simulations` and a `set of notebooks` that renders into a `signed pdf` report that can be shared. 

In this section you can list all the generated report under `.citros/report` folder, you can `generate` a new report or `validate` an existing one. 